]> SALOME platform Git repositories - modules/shaper.git/commitdiff
Salome HOME
Replace NewGeom text to SHAPER
authornds <nds@opencascade.com>
Wed, 24 Feb 2016 08:41:09 +0000 (11:41 +0300)
committernds <nds@opencascade.com>
Wed, 24 Feb 2016 08:41:09 +0000 (11:41 +0300)
35 files changed:
CMakeCommon/UnitTest.cmake
README
doc/Shaper/general_architecture.doc
doc/first_feature_help.doc
eclipse.sh
env.sh
env_Salome.bat
env_linux.sh
env_salome.sh
env_standalone.sh
linux_run.sh
make.sh
msvc10_env.bat
solver.sh
src/Config/Config_Keywords.h
src/Config/Config_XMLReader.cpp
src/Model/Model_AttributeSelection.h
src/ModuleBase/ModuleBase_Preferences.cpp
src/ModuleBase/ModuleBase_Preferences.h
src/SHAPERGUI/CMakeLists.txt
src/SHAPERGUI/SHAPERGUI.cpp
src/SHAPERGUI/SHAPERGUI.h
src/SHAPERGUI/SHAPERGUI_DataModel.cpp
src/SHAPERGUI/SHAPERGUI_DataModel.h
src/SHAPERGUI/SHAPERGUI_NestedButton.h
src/SHAPERGUI/SHAPERGUI_OCCSelector.h
src/SHAPERGUI/SHAPERGUI_SalomeViewer.cpp
src/SHAPERGUI/SHAPERGUI_SalomeViewer.h
src/SHAPERGUI/resources/LightApp.xml
src/SHAPERGUI/resources/SalomeApp.xml
src/SHAPERGUI/resources/newgeom.png [deleted file]
src/SHAPERGUI/resources/shaper.png [new file with mode: 0644]
src/SketcherPrs/SketcherPrs_SymbolPrs.cpp
src/XGUI/XGUI_SalomeConnector.h
src/XGUI/XGUI_Workshop.cpp

index 3685b2b2bdada4cf6d91004384bb74b4c2c41902..c7b9245a0e58c9967145b170bc7fb7590bf7d8da 100644 (file)
@@ -1,7 +1,7 @@
 ## Copyright (C) 2014-20xx CEA/DEN, EDF R&D
 
 #
-# NewGeom unit test system
+# SHAPER unit test system
 # How to use:
 # INCLUDE(UnitTest)
 # ...
@@ -54,10 +54,10 @@ MACRO(ADD_UNIT_TESTS)
                COMMAND ${PYTHON_EXECUTABLE} ${aTestFileName})
       if (WIN32) # different path to libraries variable name
         SET_TESTS_PROPERTIES(${aTestName} PROPERTIES
-               ENVIRONMENT "PATH=${_JUSTPATH};PYTHONPATH=${_PYTHONPATH};NEW_GEOM_CONFIG_FILE=${_CONFIG_FILE}")
+               ENVIRONMENT "PATH=${_JUSTPATH};PYTHONPATH=${_PYTHONPATH};SHAPER_CONFIG_FILE=${_CONFIG_FILE}")
       else()
         SET_TESTS_PROPERTIES(${aTestName} PROPERTIES
-               ENVIRONMENT "LD_LIBRARY_PATH=${_LD_LIBRARY_PATH};PYTHONPATH=${_PYTHONPATH};NEW_GEOM_CONFIG_FILE=${_CONFIG_FILE}")
+               ENVIRONMENT "LD_LIBRARY_PATH=${_LD_LIBRARY_PATH};PYTHONPATH=${_PYTHONPATH};SHAPER_CONFIG_FILE=${_CONFIG_FILE}")
       endif()
       # Debug output...
       #MESSAGE(STATUS "Test added: ${aTestName} file: ${aTestFileName}")
diff --git a/README b/README
index 75b6ec213aaa3dd992e002b9f99f268d1853295c..629455b99b2f8ea5b8c58172a6d8809578b0b0b0 100644 (file)
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-NewGEOM version 2.0.0
+SHAPER version 2.0.0
 
 Compilation on LINUX:
 =====================
@@ -31,7 +31,7 @@ Or without environment call:
 Compilation on Windows:
 =======================
   cd <sources_directory>
-  buildNewGEOM_rel.bat
+  buildSHAPER_rel.bat
 
 It will launch the Visual Studio 2010. In it build for: "ALL_BUILD" and then "INSTALL" projects.
 Launch:
@@ -43,6 +43,6 @@ For compilation on Windows basing on SALOME products already installed please us
 msvc9_env_Salome.bat
 
 SALOME_ROOT_DIR is needed to be correctly set or located in "SALOME" folder of
-parent to NewGEOM folder. For the current moment SALOME 7.3.0 compiled on
+parent to SHAPER folder. For the current moment SALOME 7.3.0 compiled on
 Visual Studio 2008 compiler is supported.
 
index 11bb3012ea71f52625646064266f0534f749d766..3041bfed3757d0cbfc9c83afab49ce100a570ccb 100644 (file)
@@ -3,7 +3,7 @@
 
 A Shaper module is made of Workshop (see XGUI_Workshop) which loads a Module (see ModuleBase_IModule), connecting its features with GUI, providing it with services for launching of operations, tools for user inputs and visualisation of results. The Module can consist of one or several plug-ins which provide implementation of Module features. Each plug-in can implement one or several features. These features can be structured by Workbenches within Workshop. Workshop provides introducing of these Workbenches within main window in form of menus or/and tool bars.
 \n
-Workshop interacts with a Module with help of specific interface defined in ModuleBase package. Each module for NewGeom application has to implement ModuleBase_IModile interface.
+Workshop interacts with a Module with help of specific interface defined in ModuleBase package. Each module for SHAPER application has to implement ModuleBase_IModile interface.
 \n
 A Module manages a one document (ModelAPI_Document). This document consists of a one root document and several, loaded by request, sub-documents. Each sub-document can be stored in a single file. 
 \n
@@ -30,11 +30,11 @@ Each sub-document contains a data of a one Part. When the user saves its session
 
 <h2>SALOME module definition</h2>
 
-The NewGeom package allows to launch the application as one of the module of SALOME platform. In that case all user interface elements are integrated into SALOME platform: the \ref Salome package is used for this connection.
+The SHAPERGUI package allows to launch the application as one of the module of SALOME platform. In that case all user interface elements are integrated into SALOME platform: the \ref Salome package is used for this connection.
 \n
 To integrate Shaper into SALOME the next steps are done:
 <ol>
-<li> LightApp_Module class from SALOME GUI LightApp package is redefined (see NewGeom_Module). This redefined class provides a connection between LightApp_Module interface and Workshop object of the application.</li>
+<li> LightApp_Module class from SALOME GUI LightApp package is redefined (see SHAPERGUI). This redefined class provides a connection between LightApp_Module interface and Workshop object of the application.</li>
 <li>Provide Workshop with a <i>SALOME</i> mode of launching in SALOME environment. In this case it is launched without its own main window, 3d viewer and main menu.</li>
 <li>In <i>SALOME</i> mode workshop uses:
   <ol>
@@ -48,9 +48,9 @@ To integrate Shaper into SALOME the next steps are done:
 </li>
 <li>Each workbench is defined as a menu in main menu bar of SALOME desktop and as a tool bar with corresponded title.</li>
 <li>Each feature in the workbench is defined as a menu item in the corresponded menu and a button in the corresponded tool bar.</li>
-<li>Object Browser of SALOME is hidden on activation of NewGEOM and restored on its deactivation.</li>
-<li>Object Browser and Property panel of NewGEOM is shown on activation of the module and hidden on its deactivation.</li>
-<li>Persistent of NewGEOM is compatible with persistent of SALOME. On saving of SALOME study the content of NewGEOM data structure is saved into study also and restored on restoring of study.</li>
+<li>Object Browser of SALOME is hidden on activation of SHAPER and restored on its deactivation.</li>
+<li>Object Browser and Property panel of SHAPER is shown on activation of the module and hidden on its deactivation.</li>
+<li>Persistent of SHAPER is compatible with persistent of SALOME. On saving of SALOME study the content of SHAPERM data structure is saved into study also and restored on restoring of study.</li>
 </ol>
 
 */
index fc7f1f9ebaecfdac6ef9144b02b4b1f68521c073..233e9fd3c323fd8488c9609a885ab26474bb2255 100644 (file)
@@ -1,7 +1,7 @@
 /*!
 \page first_feature_help How to create custom features or plugins
 
-A NewGeom module consists of one or several plug-ins which provide implementation of Module features. To extend the application functionality, developers are able to add their own features into existent plugins. Also, it is possible to create a custom plugin, if necessary. 
+A SHAPER module consists of one or several plug-ins which provide implementation of Module features. To extend the application functionality, developers are able to add their own features into existent plugins. Also, it is possible to create a custom plugin, if necessary. 
 \n
 This document describes the basic principles of plugin/feature system and shows how to use the API for writing a feature or plugin. Currently, the API is available for C++ and Python languages. Plugin, written in C++ is a shared object (dll); For Python, it is regular python module, with *.py extension. 
 \n
index 8603025a697f9b2d7bf51cd6938e25bb4d50ae53..d4036fb363efa2979ba571e0e1cb2262dbb3c844 100755 (executable)
@@ -9,7 +9,7 @@ cd ${BUILD_DIR}
 CMAKE_ARGS="-D_ECLIPSE_VERSION=4.3"
 CMAKE_ARGS="${CMAKE_ARGS} -DCMAKE_BUILD_TYPE=Debug"
 CMAKE_ARGS="${CMAKE_ARGS} -DCMAKE_ECLIPSE_GENERATE_SOURCE_PROJECT=ON"
-CMAKE_ARGS="${CMAKE_ARGS} -DCMAKE_INSTALL_PREFIX:PATH=${NEWGEOM_ROOT_DIR}"
+CMAKE_ARGS="${CMAKE_ARGS} -DCMAKE_INSTALL_PREFIX:PATH=${SHAPER_ROOT_DIR}"
 CMAKE_ARGS="${CMAKE_ARGS} -DPYTHON_EXECUTABLE=${PYTHONHOME}/bin/python"
 CMAKE_ARGS="${CMAKE_ARGS} -DUSE_TEST_COVERAGE=OFF"
 CMAKE_ARGS="${CMAKE_ARGS} ${SOURCES_DIR}"
diff --git a/make.sh b/make.sh
index 491d8f394ff5ab7f975207e4d94600f001cd3085..2ebe12011854c06aad3b33df2221ef0d973cc436 100755 (executable)
--- a/make.sh
+++ b/make.sh
@@ -34,7 +34,7 @@ fi
 CMAKE_ARGS=""
 CMAKE_ARGS="${CMAKE_ARGS} -DCMAKE_BUILD_TYPE=${BUILD_TYPE:-Release}"
 CMAKE_ARGS="${CMAKE_ARGS} -DUSE_TEST_COVERAGE=${USE_TEST_COVERAGE:-OFF}"
-CMAKE_ARGS="${CMAKE_ARGS} -DCMAKE_INSTALL_PREFIX:PATH=${NEWGEOM_ROOT_DIR}"
+CMAKE_ARGS="${CMAKE_ARGS} -DCMAKE_INSTALL_PREFIX:PATH=${SHAPER_ROOT_DIR}"
 CMAKE_ARGS="${CMAKE_ARGS} ${SOURCES_DIR}"
 
 mkdir -p ${BUILD_DIR}
index aaa3a32c1981732ee2f2eeb4646fe8d177839a46..8d8aa6eb8f30ef4feb6eb40bc423b7eb90070b78 100644 (file)
@@ -173,7 +173,7 @@ set PATH=%CMAKEDIR%\bin;%PATH%
 @REM -------------------------
 @REM OPENPARTS
 @SET SHAPER_ROOT_DIR=%ROOT_DIR%\install
-@SET NEW_GEOM_CONFIG_FILE=%SHAPER_ROOT_DIR%\plugins
+@SET SHAPER_CONFIG_FILE=%SHAPER_ROOT_DIR%\plugins
 @SET PATH=%SHAPER_ROOT_DIR%\swig;%SHAPER_ROOT_DIR%\plugins;%SHAPER_ROOT_DIR%\bin;%PATH%
 @SET PYTHONPATH=%SHAPER_ROOT_DIR%\swig;%SHAPER_ROOT_DIR%\plugins;%SHAPER_ROOT_DIR%\addons;%SHAPER_ROOT_DIR%\pythonAPI;%PYTHONPATH%
 @SET SHAPERResources=%SHAPER_ROOT_DIR%\resources
index fb002a6af65ea49f70d25e909dc4517d1c7e200f..2e6ed445ee3c0c059f76d14b9dc27b491e0bc173 100755 (executable)
diff --git a/env.sh b/env.sh
index ab13dd393f00b5fb2ab37f0d2cae70c79df7ea19..15f52740115ba542cf601fcfba4eeb6e83954dd8 100644 (file)
--- a/env.sh
+++ b/env.sh
@@ -18,6 +18,6 @@ fi
 source env_config.sh
 
 # Path to solvespace-2
-export NEWGEOM_PDIR=/dn48/newgeom/common/products
+export SHAPER_PDIR=/dn48/newgeom/common/products
 # Path to install directory
-export NEWGEOM_ROOT_DIR=$(cd .. && pwd)/install
+export SHAPER_ROOT_DIR=$(cd .. && pwd)/install
index 0a97e7c729832a5b8d3b6b2441953d2190e507ef..2a7d7a437062fc4d15cda83f4823418e3d72218e 100644 (file)
@@ -99,7 +99,7 @@ IF "%ARCH%" == "Win64" (
   )
 )
 
-@SET NEW_GEOM_CONFIG_FILE=%ROOT_DIR%\install\plugins
+@SET SHAPER_CONFIG_FILE=%ROOT_DIR%\install\plugins
 @SET SHAPER_ROOT_DIR=%ROOT_DIR%\install
 @SET PATH=%SHAPER_ROOT_DIR%\swig;%SHAPER_ROOT_DIR%\plugins;%SHAPER_ROOT_DIR%\bin;%PATH%
 @SET PYTHONPATH=%SHAPER_ROOT_DIR%\swig;%SHAPER_ROOT_DIR%\plugins;%SHAPER_ROOT_DIR%\addons;%SHAPER_ROOT_DIR%\pythonAPI;%PYTHONPATH%
index 2aaa7dbbd50f67697ac7d27597e46beb9f98d558..0304d3338af41a5d1f2fed54e21775d3c774d5ac 100644 (file)
@@ -3,10 +3,10 @@
 # This script uses:
 #
 # INST_ROOT - path of SALOME (env_products.sh)
# NEWGEOM_PDIR - path of PRODUCTS for NEWGEOM (SolveSpace, lcov)
# NEWGEOM_ROOT_DIR - path of NEWGEOM installation
 
-for path in INST_ROOT NEWGEOM_PDIR NEWGEOM_ROOT_DIR; do
+for path in INST_ROOT SHAPER_PDIR SHAPER_ROOT_DIR; do
   if [[ -z ${!path+x} ]]; then
     echo "${path} not found."; exit 1
   else
@@ -20,25 +20,25 @@ source ${INST_ROOT}/$(cd ${INST_ROOT} && ls *env_products.sh)
 set -u
 
 #------ SolveSpace ------
-export SOLVESPACE_ROOT_DIR=${NEWGEOM_PDIR}/solvespace-2.1
+export SOLVESPACE_ROOT_DIR=${SHAPER_PDIR}/solvespace-2.1
 export LD_LIBRARY_PATH=${SOLVESPACE_ROOT_DIR}/lib:${LD_LIBRARY_PATH}
 ##
 
 #------ PlaneGCS ------
-export PLANEGCS_ROOT_DIR=${NEWGEOM_PDIR}/planegcs-0.16
+export PLANEGCS_ROOT_DIR=${SHAPER_PDIR}/planegcs-0.16
 export LD_LIBRARY_PATH=${PLANEGCS_ROOT_DIR}/lib:${LD_LIBRARY_PATH}
 ##
 
 #------ Eigen ------
-export EIGEN_ROOT_DIR=${NEWGEOM_PDIR}/eigen-3.2.7
+export EIGEN_ROOT_DIR=${SHAPER_PDIR}/eigen-3.2.7
 ##
 
 #------ Boost ------
-export BOOST_ROOT_DIR=${NEWGEOM_PDIR}/boost-1.52.0
+export BOOST_ROOT_DIR=${SHAPER_PDIR}/boost-1.52.0
 ##
 
 #------ lcov ------
-export LCOV_ROOT_DIR=${NEWGEOM_PDIR}/lcov-1.11
+export LCOV_ROOT_DIR=${SHAPER_PDIR}/lcov-1.11
 export PATH=${LCOV_ROOT_DIR}/bin:${PATH}
 ##
 
@@ -51,9 +51,9 @@ export LIB=${LD_LIBRARY_PATH}
 export PATH=${CASROOT}:${PATH}
 ##
 
-#------ NewGEOM ------
-export PATH=${NEWGEOM_ROOT_DIR}/bin:${NEWGEOM_ROOT_DIR}/plugins:${PATH}
-export PYTHONPATH=${NEWGEOM_ROOT_DIR}/swig:${NEWGEOM_ROOT_DIR}/plugins:${NEWGEOM_ROOT_DIR}/addons:${NEWGEOM_ROOT_DIR}/PythonAPI:${PYTHONPATH}
-export LD_LIBRARY_PATH=${NEWGEOM_ROOT_DIR}/bin:${NEWGEOM_ROOT_DIR}/swig:${NEWGEOM_ROOT_DIR}/plugins:${LD_LIBRARY_PATH}
-export NEW_GEOM_CONFIG_FILE=${NEWGEOM_ROOT_DIR}/plugins
-export NewGeomResources=${NEWGEOM_ROOT_DIR}/resources
+#------ SHAPER ------
+export PATH=${SHAPER_ROOT_DIR}/bin:${SHAPER_ROOT_DIR}/plugins:${PATH}
+export PYTHONPATH=${SHAPER_ROOT_DIR}/swig:${SHAPER_ROOT_DIR}/plugins:${SHAPER_ROOT_DIR}/addons:${SHAPER_ROOT_DIR}/PythonAPI:${PYTHONPATH}
+export LD_LIBRARY_PATH=${SHAPER_ROOT_DIR}/bin:${SHAPER_ROOT_DIR}/swig:${SHAPER_ROOT_DIR}/plugins:${LD_LIBRARY_PATH}
+export SHAPER_CONFIG_FILE=${SHAPER_ROOT_DIR}/plugins
+export SHAPERResources=${SHAPER_ROOT_DIR}/resources
index 7aa4b6992e0260ed3440a323f356eaa503fa9555..631a01214287afe4cba2dcd870a9daaa5d748869 100644 (file)
@@ -12,4 +12,4 @@ source ${TOOLS_DIR}/env_linux.sh
 
 # Correcting path which defined with error
 export LD_LIBRARY_PATH=${KERNEL_ROOT_DIR}/lib/salome:${LD_LIBRARY_PATH}
-export SalomeAppConfig=${NEWGEOM_ROOT_DIR}/share/salome/resources/newgeom:${GUI_ROOT_DIR}/share/salome/resources/gui
+export SalomeAppConfig=${SHAPER_ROOT_DIR}/share/salome/resources/shaper:${GUI_ROOT_DIR}/share/salome/resources/gui
index d4ca856c38764951c69cbaeb4ce17a2161821e9f..e04a1e0aea2add4ab880d6a01108f45bef45c15d 100644 (file)
@@ -15,5 +15,5 @@ export PATH=${SUIT_DIR}/bin:${PATH}
 export LD_LIBRARY_PATH=${SUIT_DIR}/lib/salome:${LD_LIBRARY_PATH}
 
 #export LD_LIBRARY_PATH=${KERNEL_ROOT_DIR}/lib/salome:${LD_LIBRARY_PATH}
-#export LightAppConfig=${NEWGEOM_ROOT_DIR}/share/salome/resources/newgeom:${GUI_ROOT_DIR}/share/salome/resources/gui
-export LightAppConfig=${NEWGEOM_ROOT_DIR}/share/salome/resources/newgeom
+#export LightAppConfig=${SHAPER_ROOT_DIR}/share/salome/resources/shaper:${GUI_ROOT_DIR}/share/salome/resources/gui
+export LightAppConfig=${SHAPER_ROOT_DIR}/share/salome/resources/shaper
index f84755c194e9d9eb4c719d4d011de04b02cbe2fa..aad0cde3e4ce2df46d450b10b390dc5519fc5aa8 100755 (executable)
@@ -5,6 +5,6 @@ source ${TOOLS_DIR}/env_standalone.sh
 
 ${TOOLS_DIR}/solver.sh "$@"
 
-APP=${NEWGEOM_ROOT_DIR}/bin/GeomApp
+APP=${SHAPER_ROOT_DIR}/bin/GeomApp
 
 ${APP}
@@ -3,10 +3,10 @@
 #
 # INST_ROOT - path of SALOME (env_products.sh)
-# NEWGEOM_PDIR - path of PRODUCTS for NEWGEOM (SolveSpace, lcov)
-# NEWGEOM_ROOT_DIR - path of NEWGEOM installation
+# SHAPER_PDIR - path of PRODUCTS for SHAPER (SolveSpace, lcov)
+# SHAPER_ROOT_DIR - path of SHAPER installation
 
--- a/solver.sh
+++ b/solver.sh
@@ -2,7 +2,7 @@
 #
 # Modify plugins.xml to switch solver
 
-export PLUGINS_PATH=${PLUGINS_PATH:-${NEWGEOM_ROOT_DIR}/plugins/plugins.xml}
+export PLUGINS_PATH=${PLUGINS_PATH:-${SHAPER_ROOT_DIR}/plugins/plugins.xml}
 
 while [[ $# > 0 ]]; do
   key="$1"
index 609d7907a211c9428ff3815fe6abb5679c038f81..e26ba0aa42a52416e45d5037b233628d980d4be2 100644 (file)
@@ -99,9 +99,6 @@ const static char* PLUGIN_LIBRARY = "library";
 const static char* PLUGIN_SCRIPT = "script";
 const static char* PLUGIN_DEPENDENCY = "dependency";
 
-const static char* PLUGIN_PLATFORM_SALOME = "salome";
-const static char* PLUGIN_PLATFORM_NEWGEOM = "openparts";
-
 /*
  * Hardcoded xml entities of dataModel.xml
  */
index b6bbc0ecc3cb98a2ea4759f3b3957620541404df..a995f3c7191cdb21dfcdd108d18aaad898174db3 100644 (file)
@@ -41,7 +41,7 @@ Config_XMLReader::Config_XMLReader(const std::string& theXmlFileName)
    * to use environment variable (at least for the current moment)
    */
   if (prefix.empty()) {
-    char* anEnv = getenv("NEW_GEOM_CONFIG_FILE");
+    char* anEnv = getenv("SHAPER_CONFIG_FILE");
     if (anEnv) {
       prefix = std::string(anEnv);
     }
index 665758341c1c8aa1ac158eabd1369b78d660314d..5c7d3c358a0494fefab375d32faa667e71178dce 100644 (file)
@@ -54,7 +54,7 @@ public:
   
   /// Returns an Id of the selection
   /// NOTE: This method has been added for temporary export of groups towards old GEOM
/// It should then be removed when a direct use of objects from NewGeom
   /// will be possible from SMESH module of SALOME.
   MODEL_EXPORT virtual int Id();
 
index bc7864833c5abb214a1ba6dfad763a233a0d9fc3..03aec786b07bbbb57d7f2efa1c44308e45803801 100644 (file)
@@ -26,7 +26,7 @@ SUIT_ResourceMgr* ModuleBase_Preferences::myResourceMgr = 0;
 SUIT_ResourceMgr* ModuleBase_Preferences::resourceMgr()
 {
   if (!myResourceMgr) {
-    myResourceMgr = new SUIT_ResourceMgr("NewGeom");
+    myResourceMgr = new SUIT_ResourceMgr("SHAPER");
     myResourceMgr->setCurrentFormat("xml");
   }
   return myResourceMgr;
index c3f31b76e732213e964ec3c049fcf64ef101b60a..cae9af663199dc61fb451c767a5dbf844a4db024 100644 (file)
@@ -42,7 +42,7 @@ class MODULEBASE_EXPORT ModuleBase_Preferences
   static SUIT_ResourceMgr* resourceMgr();
 
   /// Sets a resource manager
/// It is used in case of necessity to define external resource manager (not NewGeom)
   /// \param theMgr resource manager
   static void setResourceMgr(SUIT_ResourceMgr* theMgr) { myResourceMgr = theMgr; }
 
index c8616d38333bed33ec680e166e2e4bb1daccb4fd..e21ab22061772be8f8a96b8214938cc300ed23a2 100644 (file)
@@ -27,7 +27,7 @@ SET(PROJECT_SOURCES
 SET(PROJECT_RESOURCES
        resources/LightApp.xml
        resources/SalomeApp.xml
-       resources/newgeom.png
+       resources/shaper.png
 )
 
 SET(PROJECT_LIBRARIES
@@ -58,15 +58,15 @@ INCLUDE_DIRECTORIES(${PROJECT_SOURCE_DIR}/src/XGUI
                     ${CAS_INCLUDE_DIRS}
 )
 
-ADD_LIBRARY(SHAPERGUI SHARED 
+ADD_LIBRARY(SHAPER SHARED 
        ${PROJECT_SOURCES} 
        ${PROJECT_HEADERS} 
 )
 
-ADD_DEPENDENCIES(SHAPERGUI XGUI)
+ADD_DEPENDENCIES(SHAPER XGUI)
 
 # The Qt5Widgets_LIBRARIES variable also includes QtGui and QtCore
-TARGET_LINK_LIBRARIES(SHAPERGUI ${PROJECT_LIBRARIES})
+TARGET_LINK_LIBRARIES(SHAPER ${PROJECT_LIBRARIES})
 
-INSTALL(TARGETS SHAPERGUI DESTINATION bin)
+INSTALL(TARGETS SHAPER DESTINATION bin)
 INSTALL(FILES ${PROJECT_RESOURCES} DESTINATION share/salome/resources/shaper )
index 5c0a2833a0e410ef991534dd291ba8152a3f3f35..7bf260cdb5aa0e64f8fe5ea0021483615f46e05d 100644 (file)
@@ -96,7 +96,7 @@ private:
 
 //******************************************************
 SHAPERGUI::SHAPERGUI()
-    : LightApp_Module("NewGeom"),
+    : LightApp_Module("SHAPER"),
       mySelector(0), myIsOpened(0), myPopupMgr(0)
 {
   myWorkshop = new XGUI_Workshop(this);
@@ -146,7 +146,7 @@ void SHAPERGUI::connectToStudy(CAM_Study* theStudy)
   // if there are created viewer managers, we should try to create viewer
   // selector and initialize viewer with it. It sets interactive contect to the 
   // proxy viewer. If study is opened, CAM application calls this method before the open() of data model
// the NewGeom data model is specific and during open(load) redisplay signals are flushed, so
   // we need to connect to the viewer before it. Here, it seems the most appropriate place for this
   // according to SALOME architecture.
   if (!mySelector) {
index eb993b0c7c835a44ea4681a42affef1b8b263241..7efea881ab2608e69e9b22d510a69e9fe383dd84 100644 (file)
@@ -114,10 +114,10 @@ Q_OBJECT
     return myProxyViewer;
   }
 
//! Returns list of defined actions (just by NewGeom module)
   virtual QList<QAction*> commandList() const;
 
//! Returns list of Ids of defined actions (just by NewGeom module)
   virtual QStringList commandIdList() const;
 
   /// Redefinition of virtual function. 
index 2aa2ef034201050593351f25e32326d2be521f1b..df6a6ae3fc9e2b57234cb7bda2df30b36812afe5 100644 (file)
@@ -36,7 +36,7 @@ bool SHAPERGUI_DataModel::open(const QString& thePath, CAM_Study* theStudy, QStr
   // If the file is Multi(contain all module files inside), the open SALOME functionality creates
   // these files in a temporary directory. After the open functionality is finished, it removes
   // these files (in the full SALOME mode).
// The postponed loading of the files is realized in the NewGEOM module. So, it is important do
   // not remove the opened files.
   // The following code creates a new tmp directory with a copy of files.
   QString aTmpDir = theFiles.first();
index f07b913bf03a45092bd94e8f734f781cefbbe862..2383f832bd9bbb99ec989a85c51d5b7678a29d63 100644 (file)
@@ -1,8 +1,8 @@
 // Copyright (C) 2014-20xx CEA/DEN, EDF R&D
 
 
-#ifndef NEWGEOM_DATAMODEL_H
-#define NEWGEOM_DATAMODEL_H
+#ifndef SHAPERGUI_DATAMODEL_H
+#define SHAPERGUI_DATAMODEL_H
 
 #include "SHAPER_SHAPERGUI.h"
 #include <LightApp_DataModel.h>
index bb2bb7cb490a28c5a9b490bb2cb3359c1ed14cfb..2b55ee3764f6721c6b618c323eff1ffc26375c5f 100644 (file)
@@ -5,8 +5,8 @@
  *      Author: sbh
  */
 
-#ifndef SRC_NEWGEOM_NEWGEOM_NESTEDBUTTON_H_
-#define SRC_NEWGEOM_NEWGEOM_NESTEDBUTTON_H_
+#ifndef SRC_SHAPERGUI_NESTEDBUTTON_H_
+#define SRC_SHAPERGUI_NESTEDBUTTON_H_
 
 #include <QWidgetAction>
 
@@ -50,4 +50,4 @@ class SHAPERGUI_NestedButton : public QWidgetAction
   QToolButton* myThisButton; ///< main button
 };
 
-#endif /* SRC_NEWGEOM_NEWGEOM_NESTEDBUTTON_H_ */
+#endif /* SRC_SHAPERGUI_NESTEDBUTTON_H_ */
index 9d9e44e31433097f2a98276f83cd72ceef8222a2..3ee36b4ced6aa1e349880360db5069aca7214da8 100644 (file)
@@ -9,7 +9,7 @@
 
 /**
 * \ingroup Salome
* Redefinition of standard OCC selector in order to adapt it to NewGeom needs
 */
 class SHAPERGUI_EXPORT SHAPERGUI_OCCSelector : public LightApp_OCCSelector
 {
index b4a65ead87a200e4461b9420f3638b637b3ecd7c..e31903dc438e223dee05e5d10eaeee58be5f36b1 100644 (file)
@@ -314,7 +314,7 @@ bool SHAPERGUI_SalomeViewer::enableDrawMode(bool isEnabled)
 
 //**********************************************
 void SHAPERGUI_SalomeViewer::reconnectActions(SUIT_ViewWindow* theWindow,
-                                            const bool theUseNewGeomSlot)
+                                            const bool theUseSHAPERSlot)
 {
   OCCViewer_ViewWindow* aWindow = dynamic_cast<OCCViewer_ViewWindow*>(theWindow);
   if (!aWindow)
@@ -324,7 +324,7 @@ void SHAPERGUI_SalomeViewer::reconnectActions(SUIT_ViewWindow* theWindow,
   if (!anAction)
     return;
 
-  if (theUseNewGeomSlot) {
+  if (theUseSHAPERSlot) {
     anAction->disconnect(anAction, SIGNAL(toggled(bool)),
                          theWindow, SLOT(onTrihedronShow(bool)));
     anAction->connect(anAction, SIGNAL(toggled(bool)),
index 3e34b603aebf3b8dc3d142767d876b387dd28888..e97c3e10b5a02e78cf5827b0d3596edd23be8250 100644 (file)
@@ -24,7 +24,7 @@ class SUIT_ViewManager;
 
 /**
 * \ingroup Salome
-* A class for providing access of NewGeom functionality to 
+* A class for providing access of SHAPERGUI functionality to 
 * SALOME view window functionality
 */
 class SHAPERGUI_SalomeView: public ModuleBase_IViewWindow
@@ -58,7 +58,7 @@ private:
 
 /**
 * \ingroup Salome
-* A class for providing access of NewGeom functionality to 
+* A class for providing access of SHAPERGUI functionality to 
 * SALOME viewer functionality
 */
 class SHAPERGUI_SalomeViewer : public ModuleBase_IViewer
@@ -102,7 +102,7 @@ Q_OBJECT
   virtual bool enableDrawMode(bool isEnabled);
 
   //! For some signals it disconnects the window from usual signal and connect it to the module ones
-  void reconnectActions(SUIT_ViewWindow* theWindow, const bool theUseNewGeomSlot);
+  void reconnectActions(SUIT_ViewWindow* theWindow, const bool theUseSHAPERSlot);
 
   //! Perfroms the fit all for the active view
   virtual void fitAll();
index 35f5954da3ae8e0e5dcdfef5d3c10a6fff4fb742..4fc4cc72a7f1ffc771513c058a3ec1d24ec7c25f 100644 (file)
 
 -->
 <document>
-  <section name="NewGeom">
+  <section name="SHAPER">
     <!-- Major module parameters -->
-    <parameter name="name" value="NewGeom"/>
-    <parameter name="icon" value="newgeom.png"/>
+    <parameter name="name" value="Shaper"/>
+    <parameter name="icon" value="shaper.png"/>
     <parameter name="version" value="2.1.2"/>
-    <parameter name="documentation" value="newgeom_help"/>
+    <parameter name="documentation" value="shaper_help"/>
   </section>
-  <section name="newgeom_help" >
+  <section name="shaper_help" >
     <parameter name="sub_menu"          value="%1 module"/>
-    <parameter name="Developer's Guide" value="%${NEWGEOM_ROOT_DIR}/doc/tui/index.html"/>
+    <parameter name="Developer's Guide" value="%SHAPER_ROOT_DIR%/share/doc/salome/tui/SHAPER/index.html"/>
+    <parameter name="User's Guide"      value="%SHAPER_ROOT_DIR%/share/doc/salome/gui/SHAPER/index.html"/>
   </section>
   <section name="resources">
     <!-- Module resources -->
-    <parameter name="NewGeom" value="${NEWGEOM_ROOT_DIR}/share/salome/resources/newgeom"/>
+    <parameter name="SHAPER" value="${SHAPER_ROOT_DIR}/share/salome/resources/shaper"/>
   </section>
 </document>
index 0df9ffd6209252effdf681fd8d86e3ffc7ddd5f3..cef46113bcadb66c900ff0ab6b88c0350f600107 100644 (file)
 <document>
   <section name="launch">
     <!-- SALOME launching parameters -->
-    <parameter name="modules"    value="GEOM,SMESH,HEXABLOCK,MED,YACS,PARAVIS,NewGeom"/>
+    <parameter name="modules"    value="GEOM,SMESH,HEXABLOCK,MED,YACS,PARAVIS,SHAPER"/>
   </section>
-  <section name="NewGeom">
+  <section name="SHAPER">
     <!-- Major module parameters -->
-    <parameter name="name" value="NewGeom"/>
-    <parameter name="icon" value="newgeom.png"/>
+    <parameter name="name" value="Shaper"/>
+    <parameter name="icon" value="shaper.png"/>
     <parameter name="version" value="2.1.2"/>
-    <parameter name="documentation" value="newgeom_help"/>
+    <parameter name="documentation" value="shaper_help"/>
   </section>
-  <section name="newgeom_help" >
+  <section name="shaper_help" >
     <parameter name="sub_menu"          value="%1 module"/>
-    <parameter name="Developer's Guide" value="%${NEWGEOM_ROOT_DIR}/doc/tui/index.html"/>
+    <parameter name="Developer's Guide" value="%SHAPER_ROOT_DIR%/share/doc/salome/tui/SHAPER/index.html"/>
+    <parameter name="User's Guide"      value="%SHAPER_ROOT_DIR%/share/doc/salome/gui/SHAPER/index.html"/>
+
   </section>
   <section name="resources">
     <!-- Module resources -->
-    <parameter name="NewGeom" value="${NEWGEOM_ROOT_DIR}/share/salome/resources/newgeom"/>
+    <parameter name="SHAPER" value="${SHAPER_ROOT_DIR}/share/salome/resources/shaper"/>
   </section>
 </document>
@@ -54,7 +54,7 @@ public:
   /// Returns an Id of the selection
   /// NOTE: This method has been added for temporary export of groups towards old GEOM
-  /// It should then be removed when a direct use of objects from NewGeom
+  /// It should then be removed when a direct use of objects from SHAPER
   /// will be possible from SMESH module of SALOME.
   MODEL_EXPORT virtual int Id();
@@ -42,7 +42,7 @@ class MODULEBASE_EXPORT ModuleBase_Preferences
 
   /// Sets a resource manager
-  /// It is used in case of necessity to define external resource manager (not NewGeom)
+  /// It is used in case of necessity to define external resource manager (not SHAPER)
   /// \param theMgr resource manager
   static void setResourceMgr(SUIT_ResourceMgr* theMgr) { myResourceMgr = theMgr; }
@@ -146,7 +146,7 @@ void SHAPERGUI::connectToStudy(CAM_Study* theStudy)
   // selector and initialize viewer with it. It sets interactive contect to the 
   // proxy viewer. If study is opened, CAM application calls this method before the open() of data model
-  // the NewGeom data model is specific and during open(load) redisplay signals are flushed, so
+  // the SHAPER data model is specific and during open(load) redisplay signals are flushed, so
   // we need to connect to the viewer before it. Here, it seems the most appropriate place for this
   // according to SALOME architecture.
@@ -114,10 +114,10 @@ Q_OBJECT
   }
 
-  //! Returns list of defined actions (just by NewGeom module)
+  //! Returns list of defined actions (just by SHAPER module)
   virtual QList<QAction*> commandList() const;
 
@@ -114,10 +114,10 @@ Q_OBJECT
   virtual QList<QAction*> commandList() const;
 
-  //! Returns list of Ids of defined actions (just by NewGeom module)
+  //! Returns list of Ids of defined actions (just by SHAPER module)
   virtual QStringList commandIdList() const;
 
@@ -36,7 +36,7 @@ bool SHAPERGUI_DataModel::open(const QString& thePath, CAM_Study* theStudy, QStr
   // these files in a temporary directory. After the open functionality is finished, it removes
   // these files (in the full SALOME mode).
-  // The postponed loading of the files is realized in the NewGEOM module. So, it is important do
+  // The postponed loading of the files is realized in the SHAPER module. So, it is important do
   // not remove the opened files.
   // The following code creates a new tmp directory with a copy of files.
@@ -9,7 +9,7 @@
 /**
 * \ingroup Salome
-* Redefinition of standard OCC selector in order to adapt it to NewGeom needs
+* Redefinition of standard OCC selector in order to adapt it to SHAPER needs
 */
 class SHAPERGUI_EXPORT SHAPERGUI_OCCSelector : public LightApp_OCCSelector
diff --git a/src/SHAPERGUI/resources/newgeom.png b/src/SHAPERGUI/resources/newgeom.png
deleted file mode 100644 (file)
index d4827e2..0000000
Binary files a/src/SHAPERGUI/resources/newgeom.png and /dev/null differ
diff --git a/src/SHAPERGUI/resources/shaper.png b/src/SHAPERGUI/resources/shaper.png
new file mode 100644 (file)
index 0000000..d4827e2
Binary files /dev/null and b/src/SHAPERGUI/resources/shaper.png differ
index 81e1f44fa43ab333796ceffd1f2e54acd8b384c1..d2daecc45a4bd60128007cd9d2b2f6d033f2154b 100644 (file)
@@ -271,7 +271,7 @@ Handle(Image_AlienPixMap) SketcherPrs_SymbolPrs::icon()
     return myIconsMap[iconName()];
   }
   // Load icon for the presentation
-  char* aEnv = getenv("NEWGEOM_ROOT_DIR");
+  char* aEnv = getenv("SHAPER_ROOT_DIR");
   if (aEnv != NULL) {
     TCollection_AsciiString aFile(aEnv);
     aFile+=FSEP;
index 50c622f018e2aee23e24dd3d9df5f219e2904c9d..ac2c60f40f8b8c06d2656cc97b70a01fa6d02773 100644 (file)
@@ -93,7 +93,7 @@ class XGUI_EXPORT XGUI_SalomeConnector
   //! Returns QAction instance by command string Id
   virtual QAction* command(const QString& theId) const = 0;
 
-  //! Returns list of defined actions (just by NewGeom module)
+  //! Returns list of defined actions (just by SHAPER module)
   virtual QList<QAction*> commandList() const = 0;
 
   //! Returns list of Ids of defined actions (just by NewGeom module)
index 3101617b62aaf1d5ec2d2371b608b8ad5713eb4b..57928b4b84341d8a55ad7e8ea92d33531e8884bd 100755 (executable)
@@ -300,12 +300,12 @@ void XGUI_Workshop::initMenu()
   //connect(aAction, SIGNAL(triggered(bool)), this, SLOT(onRebuild()));
   //salomeConnector()->addDesktopMenuSeparator("MEN_DESK_EDIT");
 
-  aAction = salomeConnector()->addDesktopCommand("SAVEAS_CMD", tr("Export NewGeom..."), tr("Export the current document into a NewGeom file"),
+  aAction = salomeConnector()->addDesktopCommand("SAVEAS_CMD", tr("Export native..."), tr("Export the current document into a native file"),
                                               QIcon(), QKeySequence(),
                                               false, "MEN_DESK_FILE");
   connect(aAction, SIGNAL(triggered(bool)), this, SLOT(onSaveAs()));
 
-  aAction = salomeConnector()->addDesktopCommand("OPEN_CMD", tr("Import NewGeom..."), tr("Import a NewGeom file"),
+  aAction = salomeConnector()->addDesktopCommand("OPEN_CMD", tr("Import native..."), tr("Import native file"),
                                               QIcon(), QKeySequence(),
                                               false, "MEN_DESK_FILE");
   connect(aAction, SIGNAL(triggered(bool)), this, SLOT(onOpen()));
@@ -1128,7 +1128,7 @@ void XGUI_Workshop::hidePropertyPanel()
   // in SALOME mode, workstack made the PyConsole the active window,
   // set the focus on it. As a result, shortcuts of the application, like
   // are processed by this console. For example Undo actions.
-  // It is possible that this code is to be moved to NewGeom package
+  // It is possible that this code is to be moved to SHAPER package
   QMainWindow* aDesktop = desktop();
   ModuleBase_Tools::activateWindow(aDesktop, "XGUI_Workshop::hidePropertyPanel()");
   ModuleBase_Tools::setFocus(aDesktop, "XGUI_Workshop::showPropertyPanel()");